CBottomSheetController<T> class

Class responsible for configuring the BottomSheets

Constructors

CBottomSheetController({required ObservableValue<CFeedBackControl<T>> observable, required WidgetByDataBuilder<T> builder, bool dismissible = true, Color? barrierColor, bool useSafeArea = true, bool useRootNavigator = true, RouteSettings? routeSettings, Color? backgroundColor, double? elevation, bool enableDrag = true, bool isScrollControlled = false, ShapeBorder? shape, Clip? clipBehavior})

Properties

backgroundColor → Color?
final
barrierColor → Color?
final
builder → WidgetByDataBuilder<T>
final
clipBehavior → Clip?
final
dismissible → bool
final
elevation → double?
final
enableDrag → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isScrollControlled → bool
final
observable → ObservableValue<CFeedBackControl<T>>
final
routeSettings → RouteSettings?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
final
useRootNavigator → bool
final
useSafeArea → bool
final

Methods

doBuild(T data, BuildContext context) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited