CDialogController<T> class

Class responsible for configuring the dialogs

Constructors

CDialogController({required ObservableValue<CFeedBackControl<T>> observable, required WidgetByDataBuilder<T> builder, bool dismissible = true, Color? barrierColor = Colors.black54, bool useSafeArea = true, bool useRootNavigator = true, RouteSettings? routeSettings})

Properties

barrierColor → Color?
final
builder → WidgetByDataBuilder<T>
final
dismissible → bool
final
hashCode → int
The hash code for this object.
no setterinherited
observable → ObservableValue<CFeedBackControl<T>>
final
routeSettings → RouteSettings?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useRootNavigator → bool
final
useSafeArea → bool
final

Methods

doBuild(T data, BuildContext context) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited