CFeedBackControl<T> class

class used to control feedbacks

Constructors

CFeedBackControl({bool show = false, T? data})
Constructor of the CFeedBackControl

Properties

data → T?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show → bool
final

Methods

copyWith({bool? show, T? data}) → CFeedBackControl<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited