CObscureTextButtonConfiguration class

Constructors

CObscureTextButtonConfiguration({bool? show, Widget? iconShow, Widget? iconHide, CObscureTextAlign align = CObscureTextAlign.right})
CObscureTextButtonConfiguration.none({Widget? iconShow, Widget? iconHide, CObscureTextAlign align = CObscureTextAlign.right})
const

Properties

align → CObscureTextAlign
final
hashCode → int
The hash code for this object.
no setterinherited
iconHide → Widget?
final
iconShow → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited