CTextFormField class

CTextFormField is a TextFormField with modifications to use ObservableValue to control.

Inheritance

Constructors

CTextFormField({Key? key, required ObservableValue<CTextFormFieldControl> observable, InputDecoration decoration = const InputDecoration(), FormFieldValidator<String>? validator, CObscureTextButtonConfiguration obscureTextButtonConfiguration = const CObscureTextButtonConfiguration.none(), ValueChanged<String>? onChanged, TextAlign textAlign = TextAlign.start, AutovalidateMode? autovalidateMode, FocusNode? focusNode, GestureTapCallback? onTap, ValueChanged<String>? onFieldSubmitted, TextInputAction? textInputAction, List<TextInputFormatter>? inputFormatters, TextInputType? keyboardType, TextStyle? style, int? minLines, int? maxLength, int maxLines = 1, bool expands = false, bool autofocus = false, bool readOnly = false, bool autocorrect = true, bool enableSuggestions = true, bool? showCursor, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, StrutStyle? strutStyle, TextDirection? textDirection, TextAlignVertical? textAlignVertical, bool enableInteractiveSelection = true, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), TextCapitalization textCapitalization = TextCapitalization.none, Iterable<String>? autofillHints, Brightness? keyboardAppearance, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, String obscuringCharacter = '•', VoidCallback? onEditingComplete, FormFieldSetter<String>? onSaved, ToolbarOptions? toolbarOptions, ValueChanged<bool>? onChangedObscuteText, TextEditingController? controller})
const

Properties

autocorrect → bool
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
autovalidateMode → AutovalidateMode?
final
buildCounter → InputCounterWidgetBuilder?
final
controller → TextEditingController?
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorRadius → Radius?
final
cursorWidth → double
final
decoration → InputDecoration
final
enableInteractiveSelection → bool
final
enableSuggestions → bool
final
expands → bool
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
final
keyboardType → TextInputType?
final
maxLength → int?
final
maxLines → int
final
minLines → int?
final
obscureTextButtonConfiguration → CObscureTextButtonConfiguration
final
obscuringCharacter → String
final
observable → ObservableValue<CTextFormFieldControl>
final
onChanged → ValueChanged<String>?
final
onChangedObscuteText → ValueChanged<bool>?
final
onEditingComplete → VoidCallback?
final
onFieldSubmitted → ValueChanged<String>?
final
onSaved → FormFieldSetter<String>?
final
onTap → VoidCallback?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPadding → EdgeInsets
final
scrollPhysics → ScrollPhysics?
final
showCursor → bool?
final
strutStyle → StrutStyle?
final
style → TextStyle?
final
textAlign → TextAlign
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
final
textDirection → TextDirection?
final
textInputAction → TextInputAction?
final
toolbarOptions → ToolbarOptions?
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CTextFormFieldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited