CTextFormFieldControl class

Class used to control CCTextFormField

Constructors

CTextFormFieldControl({bool enable = true, required String text, String? error, bool obscureText = false})
CTextFormFieldControl.empty({bool enable = true, String? error, bool obscureText = false})

Properties

enable → bool
final
error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
obscureText → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

copyWith({String? text, bool? enable, bool? obscureText, String? error}) → CTextFormFieldControl
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited